==> haskell-hoauth2-2.14.0-5-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.14.0
visibility:           public
id:                   hoauth2-2.14.0-Bt01dCEUGqHCyjDl4Mznlb
key:                  hoauth2-2.14.0-Bt01dCEUGqHCyjDl4Mznlb
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  07091eb253f419132d0d3c14d98e9fb2
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.14.0-Bt01dCEUGqHCyjDl4Mznlb
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    base64-1.0-9LNPLUzka8e3uKI1CXGfWX binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz exceptions-0.10.7
    http-conduit-2.3.9.1-HKTEHoMQbVODlt9daK23ia
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 text-2.0.2
    transformers-0.6.1.0 uri-bytestring-0.3.3.1-LSXEGwh1Eq99RsqnFGBgp8
    uri-bytestring-aeson-0.1.0.9-Br4iNV5VVhhBDRG6y4gbHn

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hoauth2-2.14.0-7-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.14.0
visibility:           public
id:                   hoauth2-2.14.0-DaCVyDpXxKl9BEI9jxEDQE
key:                  hoauth2-2.14.0-DaCVyDpXxKl9BEI9jxEDQE
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  6a7668e4bdfcf50ec4907e620cbc0a6f
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.14.0-DaCVyDpXxKl9BEI9jxEDQE
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    base64-1.0-JLGAYoBYKh9AtfiRX9PRIQ binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz exceptions-0.10.7
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 text-2.0.2
    transformers-0.6.1.0 uri-bytestring-0.3.3.1-ABUb28LEu2c8RUJdcl5zx0
    uri-bytestring-aeson-0.1.0.9-F7Kt9b9MjeW2AlXOgGIaAU

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
